/* Copyright (C) 2008-2020 Free Software Foundation, Inc.
   Written by Adam Strzelecki <ono@java.pl>

   This file is part of GNU Libidn.

   GNU Libidn is free software: you can redistribute it and/or
   modify it under the terms of either:

     * the GNU Lesser General Public License as published by the Free
       Software Foundation; either version 3 of the License, or (at
       your option) any later version.

   or

     * the GNU General Public License as published by the Free
       Software Foundation; either version 2 of the License, or (at
       your option) any later version.

   or both in parallel, as here.

   GNU Libidn is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received copies of the GNU General Public License and
   the GNU Lesser General Public License along with this program.  If
   not, see <http://www.gnu.org/licenses/>. */

#ifndef _STDBOOL_H
# define _STDBOOL_H

# define _Bool signed char
enum
{ false = 0, true = 1 };
# define bool _Bool
# define false 0
# define true 1
# define __bool_true_false_are_defined 1

#endif /* _STDBOOL_H */
